summaryrefslogtreecommitdiffstats
path: root/kuiviewer/kuiviewer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kuiviewer/kuiviewer.cpp')
-rw-r--r--kuiviewer/kuiviewer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kuiviewer/kuiviewer.cpp b/kuiviewer/kuiviewer.cpp
index e7f18950..b72599aa 100644
--- a/kuiviewer/kuiviewer.cpp
+++ b/kuiviewer/kuiviewer.cpp
@@ -78,8 +78,8 @@ KUIViewer::KUIViewer()
// itself can't do anything useful
//FIXME improve message, which Part is this referring to?
KMessageBox::error(this, i18n("Unable to locate Kuiviewer kpart."));
- kapp->quit();
- // we return here, cause kapp->quit() only means "exit the
+ tdeApp->quit();
+ // we return here, cause tdeApp->quit() only means "exit the
// next time we enter the event loop...
return;
}
@@ -98,7 +98,7 @@ void KUIViewer::load(const KURL& url)
void KUIViewer::setupActions()
{
KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
- KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
+ KStdAction::quit(tdeApp, TQ_SLOT(quit()), actionCollection());
}
void KUIViewer::saveProperties(TDEConfig* /*config*/)